@@ -46,7 +46,7 @@ Q_OBJECT
 
 public:
     kpEffectFlattenWidget (bool actOnSelection, QWidget *parent);
-    virtual ~kpEffectFlattenWidget ();
+    ~kpEffectFlattenWidget () override;
 
 
     static QColor s_lastColor1, s_lastColor2;
@@ -60,13 +60,13 @@ public:
     // kpEffectWidgetBase interface
     //
 
-    QString caption () const Q_DECL_OVERRIDE;
+    QString caption () const override;
 
-    bool isNoOp () const Q_DECL_OVERRIDE;
-    kpImage applyEffect (const kpImage &image) Q_DECL_OVERRIDE;
+    bool isNoOp () const override;
+    kpImage applyEffect (const kpImage &image) override;
 
     kpEffectCommandBase *createCommand (
-        kpCommandEnvironment *cmdEnviron) const Q_DECL_OVERRIDE;
+        kpCommandEnvironment *cmdEnviron) const override;
 
 protected slots:
     void slotEnableChanged (bool enable);
